Chromium Code Reviews
chromiumcodereview-hr@appspot.gserviceaccount.com (chromiumcodereview-hr) | Please choose your nickname with Settings | Help | Chromium Project | Gerrit Changes | Sign out
(958)

Unified Diff: src/runtime.cc

Issue 7071009: Revert "Pass undefined to JS builtins when called with implicit receiver." (Closed) Base URL: https://v8.googlecode.com/svn/branches/bleeding_edge
Patch Set: Created 9 years, 7 months ago
Use n/p to move between diff chunks; N/P to move between comments. Draft comments are only viewable by you.
Jump to:
View side-by-side diff with in-line comments
Download patch
« no previous file with comments | « src/runtime.h ('k') | src/v8natives.js » ('j') | no next file with comments »
Expand Comments ('e') | Collapse Comments ('c') | Show Comments Hide Comments ('s')
Index: src/runtime.cc
diff --git a/src/runtime.cc b/src/runtime.cc
index 3e8c0198bc6f20de0f707a2d2e9e0ee96332e425..56b7a90372a99f53b5b7156e91d06b26658fe9c9 100644
--- a/src/runtime.cc
+++ b/src/runtime.cc
@@ -4120,10 +4120,10 @@ RUNTIME_FUNCTION(MaybeObject*, Runtime_SetProperty) {
}
// Set the native flag on the function.
// This is used to decide if we should transform null and undefined
// into the global object when doing call and apply.
-RUNTIME_FUNCTION(MaybeObject*, Runtime_SetNativeFlag) {
+RUNTIME_FUNCTION(MaybeObject*, Runtime_SetES5Flag) {
NoHandleAllocation ha;
RUNTIME_ASSERT(args.length() == 1);
@@ -4131,7 +4131,7 @@ RUNTIME_FUNCTION(MaybeObject*, Runtime_SetNativeFlag) {
if (object->IsJSFunction()) {
JSFunction* func = JSFunction::cast(*object);
- func->shared()->set_native(true);
+ func->shared()->set_es5_native(true);
}
return isolate->heap()->undefined_value();
}
@@ -4120,10 +4120,10 @@ RUNTIME_FUNCTION(MaybeObject*, Runtime_SetProperty) {
}
-// Set the native flag on the function.
+// Set the ES5 native flag on the function.
// This is used to decide if we should transform null and undefined
// into the global object when doing call and apply.
« no previous file with comments | « src/runtime.h ('k') | src/v8natives.js » ('j') | no next file with comments »

Powered by Google App Engine
This is Rietveld 408576698